==> haskell-haddock-library-1.6.0-14-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-haddock-library.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: z-haddock-library-z-attoparsec
version: 1.6.0
package-name: haddock-library
lib-name: attoparsec
id: haddock-library-1.6.0-BFMJFIf41KJ3dMIQwVFPYB-attoparsec
key: haddock-library-1.6.0-BFMJFIf41KJ3dMIQwVFPYB-attoparsec
license: BSD-3-Clause
maintainer: Alex Biehl <alexbiehl@gmail.com>, Simon Hengel <sol@typeful.net>, Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>
homepage: http://www.haskell.org/haddock/
synopsis: Library exposing some functionality of Haddock.
description:
    Haddock is a documentation-generation tool for Haskell
    libraries. These modules expose some functionality of it
    without pulling in the GHC dependency. Please note that the
    API is likely to change so specify upper bounds in your
    project if you can'\''t release often. For interacting with Haddock
    itself, see the ‘haddock’ package.
category: Documentation
abi: 21607b108c7982f93151c5e1197c601a
exposed-modules:
    Data.Attoparsec.ByteString Data.Attoparsec.ByteString.Char8
    Data.Attoparsec.Combinator
hidden-modules: Data.Attoparsec Data.Attoparsec.ByteString.Buffer
                Data.Attoparsec.ByteString.FastSet
                Data.Attoparsec.ByteString.Internal Data.Attoparsec.Internal
                Data.Attoparsec.Internal.Fhthagn Data.Attoparsec.Internal.Types
                Data.Attoparsec.Number
import-dirs: /usr/lib/ghc-8.4.3/site-local/haddock-library-1.6.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/haddock-library-1.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/haddock-library-1.6.0
hs-libraries: HShaddock-library-1.6.0-BFMJFIf41KJ3dMIQwVFPYB-attoparsec
depends:
    base-4.11.1.0 bytestring-0.10.8.2 deepseq-1.4.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
haddock-interfaces: /usr/share/doc/haskell-haddock-library/html/haddock-library.haddock
haddock-html: /usr/share/doc/haskell-haddock-library/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haddock-library
version: 1.6.0
id: haddock-library-1.6.0-6ZVQnfc0Kkzgg5O1hC4N9
key: haddock-library-1.6.0-6ZVQnfc0Kkzgg5O1hC4N9
license: BSD-3-Clause
maintainer: Alex Biehl <alexbiehl@gmail.com>, Simon Hengel <sol@typeful.net>, Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>
homepage: http://www.haskell.org/haddock/
synopsis: Library exposing some functionality of Haddock.
description:
    Haddock is a documentation-generation tool for Haskell
    libraries. These modules expose some functionality of it
    without pulling in the GHC dependency. Please note that the
    API is likely to change so specify upper bounds in your
    project if you can'\''t release often. For interacting with Haddock
    itself, see the ‘haddock’ package.
category: Documentation
abi: 160f0b5fd8d0577ef763bc3898ee5229
exposed: True
exposed-modules:
    Documentation.Haddock.Doc Documentation.Haddock.Markup
    Documentation.Haddock.Parser Documentation.Haddock.Parser.Monad
    Documentation.Haddock.Types Documentation.Haddock.Utf8
hidden-modules: Documentation.Haddock.Parser.Util
import-dirs: /usr/lib/ghc-8.4.3/site-local/haddock-library-1.6.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/haddock-library-1.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/haddock-library-1.6.0
hs-libraries: HShaddock-library-1.6.0-6ZVQnfc0Kkzgg5O1hC4N9
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    transformers-0.5.5.0
    haddock-library-1.6.0-BFMJFIf41KJ3dMIQwVFPYB-attoparsec
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             haddock-library-1.6.0-BFMJFIf41KJ3dMIQwVFPYB-attoparsec=21607b108c7982f93151c5e1197c601a
haddock-interfaces: /usr/share/doc/haskell-haddock-library/html/haddock-library.haddock
haddock-html: /usr/share/doc/haskell-haddock-library/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-haddock-library-1.6.0-15-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-haddock-library.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: z-haddock-library-z-attoparsec
version: 1.6.0
package-name: haddock-library
lib-name: attoparsec
id: haddock-library-1.6.0-JaClNlYmko0Fgpp8OTqZZX-attoparsec
key: haddock-library-1.6.0-JaClNlYmko0Fgpp8OTqZZX-attoparsec
license: BSD-3-Clause
maintainer: Alex Biehl <alexbiehl@gmail.com>, Simon Hengel <sol@typeful.net>, Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>
homepage: http://www.haskell.org/haddock/
synopsis: Library exposing some functionality of Haddock.
description:
    Haddock is a documentation-generation tool for Haskell
    libraries. These modules expose some functionality of it
    without pulling in the GHC dependency. Please note that the
    API is likely to change so specify upper bounds in your
    project if you can'\''t release often. For interacting with Haddock
    itself, see the ‘haddock’ package.
category: Documentation
abi: 52393f8d3d2fe49a38d2762a2a749452
exposed-modules:
    Data.Attoparsec.ByteString Data.Attoparsec.ByteString.Char8
    Data.Attoparsec.Combinator
hidden-modules: Data.Attoparsec Data.Attoparsec.ByteString.Buffer
                Data.Attoparsec.ByteString.FastSet
                Data.Attoparsec.ByteString.Internal Data.Attoparsec.Internal
                Data.Attoparsec.Internal.Fhthagn Data.Attoparsec.Internal.Types
                Data.Attoparsec.Number
import-dirs: /usr/lib/ghc-8.4.3/site-local/haddock-library-1.6.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/haddock-library-1.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/haddock-library-1.6.0
hs-libraries: HShaddock-library-1.6.0-JaClNlYmko0Fgpp8OTqZZX-attoparsec
depends:
    base-4.11.1.0 bytestring-0.10.8.2 deepseq-1.4.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
haddock-interfaces: /usr/share/doc/haskell-haddock-library/html/haddock-library.haddock
haddock-html: /usr/share/doc/haskell-haddock-library/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haddock-library
version: 1.6.0
id: haddock-library-1.6.0-1GYYO6LznUX6Uo3pjIiRc1
key: haddock-library-1.6.0-1GYYO6LznUX6Uo3pjIiRc1
license: BSD-3-Clause
maintainer: Alex Biehl <alexbiehl@gmail.com>, Simon Hengel <sol@typeful.net>, Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>
homepage: http://www.haskell.org/haddock/
synopsis: Library exposing some functionality of Haddock.
description:
    Haddock is a documentation-generation tool for Haskell
    libraries. These modules expose some functionality of it
    without pulling in the GHC dependency. Please note that the
    API is likely to change so specify upper bounds in your
    project if you can'\''t release often. For interacting with Haddock
    itself, see the ‘haddock’ package.
category: Documentation
abi: fa6999585464588dd74a97ac5f615042
exposed: True
exposed-modules:
    Documentation.Haddock.Doc Documentation.Haddock.Markup
    Documentation.Haddock.Parser Documentation.Haddock.Parser.Monad
    Documentation.Haddock.Types Documentation.Haddock.Utf8
hidden-modules: Documentation.Haddock.Parser.Util
import-dirs: /usr/lib/ghc-8.4.3/site-local/haddock-library-1.6.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/haddock-library-1.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/haddock-library-1.6.0
hs-libraries: HShaddock-library-1.6.0-1GYYO6LznUX6Uo3pjIiRc1
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    transformers-0.5.5.0
    haddock-library-1.6.0-JaClNlYmko0Fgpp8OTqZZX-attoparsec
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             haddock-library-1.6.0-JaClNlYmko0Fgpp8OTqZZX-attoparsec=52393f8d3d2fe49a38d2762a2a749452
haddock-interfaces: /usr/share/doc/haskell-haddock-library/html/haddock-library.haddock
haddock-html: /usr/share/doc/haskell-haddock-library/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
